@@ -27,7 +27,7 @@ function(x,para) {
      xi  <- x[i]
      tmp <- xi/Asq * exp( -(xi^2 + Vsq) / (2*Asq) )
      toIo <- xi*B
-     Bo  <- besselI(toIo, n=0)
+     Bo  <- besselI(toIo, nu=0)
      if(is.finite(Bo)) {
        f[i] <- tmp*Bo
      } else {
